@@ -1,4 +1,4 @@
-/* $Id: proto.h,v 1.372.2.8 2007/12/18 15:55:48 dolorous Exp $ */
+/* $Id: proto.h 4261 2008-05-31 23:12:34Z astyanax $ */
 /**************************************************************************
  *   proto.h                                                              *
  *                                                                        *
@@ -649,7 +649,7 @@ bool do_wrap(filestruct *line);
 #if !defined(DISABLE_HELP) || !defined(DISABLE_WRAPJUSTIFY)
 ssize_t break_line(const char *line, ssize_t goal
 #ifndef DISABLE_HELP
-	, bool newline
+	, bool newln
 #endif
 	);
 #endif
