@@ -1,4 +1,4 @@
-/* $Id: text.c,v 1.163.2.5 2007/12/18 01:28:53 dolorous Exp $ */
+/* $Id: text.c 4273 2008-07-12 02:03:35Z astyanax $ */
 /**************************************************************************
  *   text.c                                                               *
  *                                                                        *
@@ -761,7 +761,7 @@ bool do_wrap(filestruct *line)
  * blank, as does a '\n' if newline is TRUE. */
 ssize_t break_line(const char *line, ssize_t goal
 #ifndef DISABLE_HELP
-	, bool newline
+	, bool newln
 #endif
 	)
 {
@@ -781,13 +781,13 @@ ssize_t break_line(const char *line, ssize_t goal
 
 	if (is_blank_mbchar(line)
 #ifndef DISABLE_HELP
-		|| (newline && *line == '\n')
+		|| (newln && *line == '\n')
 #endif
 		) {
 	    blank_loc = cur_loc;
 
 #ifndef DISABLE_HELP
-	    if (newline && *line == '\n')
+	    if (newln && *line == '\n')
 		break;
 #endif
 	}
@@ -800,6 +800,15 @@ ssize_t break_line(const char *line, ssize_t goal
 	/* In fact, the whole line displays shorter than goal. */
 	return cur_loc;
 
+#ifndef DISABLE_HELP
+    if (newln && blank_loc <= 0) {
+       /* If blank was not found or was found only first character,
+        * force line break. */
+       cur_loc -= line_len;
+       return cur_loc;
+    }
+#endif
+
     if (blank_loc == -1) {
 	/* No blank was found that was short enough. */
 	bool found_blank = FALSE;
@@ -810,7 +819,7 @@ ssize_t break_line(const char *line, ssize_t goal
 
 	    if (is_blank_mbchar(line)
 #ifndef DISABLE_HELP
-		|| (newline && *line == '\n')
+		|| (newln && *line == '\n')
 #endif
 		) {
 		if (!found_blank)
@@ -834,11 +843,11 @@ ssize_t break_line(const char *line, ssize_t goal
 
     while (*line != '\0' && (is_blank_mbchar(line)
 #ifndef DISABLE_HELP
-	|| (newline && *line == '\n')
+	|| (newln && *line == '\n')
 #endif
 	)) {
 #ifndef DISABLE_HELP
-	if (newline && *line == '\n')
+	if (newln && *line == '\n')
 	    break;
 #endif
 
@@ -2361,7 +2370,7 @@ void do_spell(void)
 void do_wordlinechar_count(void)
 {
     size_t words = 0, chars = 0;
-    ssize_t lines = 0;
+    ssize_t nlines = 0;
     size_t current_x_save = openfile->current_x;
     size_t pww_save = openfile->placewewant;
     filestruct *current_save = openfile->current;
@@ -2396,7 +2405,7 @@ void do_wordlinechar_count(void)
     /* Get the total line and character counts, as "wc -l"  and "wc -c"
      * do, but get the latter in multibyte characters. */
     if (old_mark_set) {
-	lines = openfile->filebot->lineno -
+	nlines = openfile->filebot->lineno -
 		openfile->fileage->lineno + 1;
 	chars = get_totsize(openfile->fileage, openfile->filebot);
 
@@ -2405,7 +2414,7 @@ void do_wordlinechar_count(void)
 	unpartition_filestruct(&filepart);
 	openfile->mark_set = TRUE;
     } else {
-	lines = openfile->filebot->lineno;
+	nlines = openfile->filebot->lineno;
 	chars = openfile->totsize;
     }
 
@@ -2417,7 +2426,7 @@ void do_wordlinechar_count(void)
     /* Display the total word, line, and character counts on the
      * statusbar. */
     statusbar(_("%sWords: %lu  Lines: %ld  Chars: %lu"), old_mark_set ?
-	_("In Selection:  ") : "", (unsigned long)words, (long)lines,
+	_("In Selection:  ") : "", (unsigned long)words, (long)nlines,
 	(unsigned long)chars);
 }
 #endif /* !NANO_TINY */
